@@ -32,6 +32,8 @@ struct _FancyPrefs
     gboolean block_links;
     gboolean enable_scripts;
     gboolean enable_plugins;
+    gboolean open_external;
+    gint zoom_level;
 };
 
 extern FancyPrefs fancy_prefs;
