@@ -25,7 +25,7 @@
 #include "common/utils.h"
 #include "common/defs.h"
 #include "folder.h"
-#include "hooks.h"
+#include "common/hooks.h"
 #include "procmsg.h"
 #include "mainwindow.h"
 #include "main.h"
@@ -38,6 +38,8 @@
 #include "notification_banner.h"
 #include "notification_lcdproc.h"
 #include "notification_trayicon.h"
+#include "notification_indicator.h"
+#include "notification_hotkeys.h"
 #include "notification_foldercheck.h"
 #include "notification_pixbuf.h"
 #include "plugin.h"
@@ -150,7 +152,7 @@ static gboolean my_folder_item_update_hook(gpointer source, gpointer data)
 
   g_return_val_if_fail(source != NULL, FALSE);
 
-#if defined(NOTIFICATION_LCDPROC) || defined(NOTIFICATION_TRAYICON)
+#if defined(NOTIFICATION_LCDPROC) || defined(NOTIFICATION_TRAYICON) || defined(NOTIFICATION_INDICATOR)
     notification_update_msg_counts(NULL);
 #else
     if(notify_config.urgency_hint)
@@ -210,7 +212,7 @@ gint plugin_init(gchar **error)
   bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
   /* Version check */
-  if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,1,60),
+  if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,3,22),
 			   VERSION_NUMERIC, _("Notification"), error))
     return -1;
 
@@ -349,6 +351,10 @@ gint plugin_init(gchar **error)
   if(notify_config.urgency_hint_new || notify_config.urgency_hint_unread)
 	notification_update_msg_counts(NULL);
 
+#ifdef NOTIFICATION_HOTKEYS
+  notification_hotkeys_update_bindings();
+#endif
+
   debug_print("Notification plugin loaded\n");
 
   return 0;
@@ -384,7 +390,9 @@ gboolean plugin_done(void)
 #ifdef NOTIFICATION_TRAYICON
   notification_trayicon_destroy();
 #endif
-
+#ifdef NOTIFICATION_INDICATOR
+  notification_indicator_destroy();
+#endif
   notification_core_free();
 
 #ifdef HAVE_LIBNOTIFY
@@ -392,10 +400,17 @@ gboolean plugin_done(void)
     notify_uninit();
 #endif
 
+#ifdef NOTIFICATION_HOTKEYS
+  notification_hotkeys_unbind_all();
+#endif
+
   notification_pixbuf_free_all();
 
   debug_print("Notification plugin unloaded\n");
-  return TRUE;
+
+  /* Returning FALSE here means that g_module_close() will not be called on the plugin.
+   * This is necessary, as needed libraries are not designed to be unloaded. */
+  return FALSE;
 }
 
 const gchar *plugin_name(void)
