@@ -25,6 +25,7 @@
 #include "notification_trayicon.h"
 #include "notification_prefs.h"
 #include "notification_core.h"
+#include "notification_hotkeys.h"
 #include "notification_pixbuf.h"
 #include "notification_foldercheck.h"
 
@@ -34,12 +35,11 @@
 #include "mainwindow.h"
 #include "prefs_common.h"
 #include "alertpanel.h"
-#include "menu.h"
+#include "gtk/menu.h"
 #include "addrindex.h"
 #include "gtk/manage_window.h"
 #include "common/utils.h"
 
-
 static GdkPixbuf* notification_trayicon_create(void);
 
 static void notification_trayicon_on_popup_menu(GtkStatusIcon*,guint,
@@ -236,6 +236,11 @@ void notification_update_trayicon()
   notification_core_get_msg_count(list, &count);
 
   if(!trayicon) {
+
+#ifdef NOTIFICATION_HOTKEYS
+    notification_hotkeys_update_bindings();
+#endif
+
     old_icon = notification_trayicon_create();
     if(!trayicon) {
       debug_print("Notification plugin: Could not create trayicon\n");
@@ -395,26 +400,9 @@ static GdkPixbuf* notification_trayicon_create(void)
   return trayicon_nomail;
 }
 
-/* Hide/show main window */
-void notification_trayicon_on_activate(GtkStatusIcon *status_icon,
-																			 gpointer user_data)
+void notification_trayicon_on_activate(GtkStatusIcon *status_icon, gpointer user_data)
 {
-  MainWindow *mainwin;
-  if((mainwin = mainwindow_get_mainwindow()) == NULL)
-    return;
-
-  if(GTK_WIDGET_VISIBLE(GTK_WIDGET(mainwin->window))) {
-    if((gdk_window_get_state(GTK_WIDGET(mainwin->window)->window)&GDK_WINDOW_STATE_ICONIFIED)
-       || mainwindow_is_obscured()) {
-      notification_show_mainwindow(mainwin);
-    }
-    else {
-      main_window_hide(mainwin);
-    }
-  }
-  else {
-    notification_show_mainwindow(mainwin);
-  }
+  notification_toggle_hide_show_window();
 }
 
 static void notification_trayicon_on_popup_menu(GtkStatusIcon *status_icon,
@@ -507,8 +495,8 @@ static void app_exit_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
     manage_window_focus_in(mainwin->window, NULL, NULL);
   }
 
-  if (prefs_common.clean_on_exit) {
-    if (!main_window_empty_trash(mainwin, prefs_common.ask_on_clean, TRUE))
+  if (prefs_common_get_prefs()->clean_on_exit) {
+    if (!main_window_empty_trash(mainwin, prefs_common_get_prefs()->ask_on_clean, TRUE))
       return;
   }
 
