@@ -26,6 +26,10 @@
 #include "gettext.h"
 #include <gtk/gtk.h>
 
+#if USE_PTHREAD
+#include "pthread.h"
+#endif
+
 #include "mimeview.h"
 #include "utils.h"
 #include "vcalendar.h"
@@ -35,6 +39,7 @@
 #include "vcal_interface.h"
 #include "prefs_account.h"
 #include "prefs_common.h"
+#include "menu.h"
 #include "account.h"
 #include "codeconv.h"
 #include "xml.h"
@@ -47,7 +52,7 @@
 
 MimeViewerFactory vcal_viewer_factory;
 
-static void create_meeting_from_message_cb(gpointer callback_data, guint callback_action, GtkWidget *widget);
+static void create_meeting_from_message_cb_ui(GtkAction *action, gpointer data);
 
 static GdkColor uri_color = {
 	(gulong)0,
@@ -71,6 +76,7 @@ struct _VCalViewer
 	GtkWidget *who;
 	GtkWidget *start;
 	GtkWidget *end;
+	GtkWidget *location;
 	GtkWidget *summary;
 	GtkWidget *description;
 	gchar	  *url;
@@ -83,23 +89,12 @@ struct _VCalViewer
 	GtkWidget *unavail_box;
 };
 
-static GtkItemFactoryEntry vcalendar_main_menu = {
-	N_("/Message/Create meeting from message..."),
-	NULL,
-	create_meeting_from_message_cb,
-	0,
-	NULL
-};
+static GtkActionEntry vcalendar_main_menu[] = {{
+	"Message/CreateMeeting",
+	NULL, N_("Create meeting from message..."), NULL, NULL, G_CALLBACK(create_meeting_from_message_cb_ui)
+}};
 
-static GtkItemFactoryEntry vcalendar_context_menu = {
-	N_("/Create meeting from message..."),
-	NULL,
-	create_meeting_from_message_cb,
-	0,
-	NULL
-};
-
-static void create_meeting_from_message_cb(gpointer callback_data, guint callback_action, GtkWidget *widget)
+static void create_meeting_from_message_cb_ui(GtkAction *action, gpointer data)
 {
 	MainWindow *mainwin = mainwindow_get_mainwindow();
 	SummaryView *summaryview = mainwin->summaryview;
@@ -129,7 +124,7 @@ static void create_meeting_from_message_cb(gpointer callback_data, guint callbac
 	g_free(msg);
 
 	main_window_cursor_wait(summaryview->mainwin);
-	gtk_clist_freeze(GTK_CLIST(summaryview->ctree));
+	gtk_cmclist_freeze(GTK_CMCLIST(summaryview->ctree));
 	folder_item_update_freeze();
 	inc_lock();
 
@@ -171,7 +166,7 @@ static void create_meeting_from_message_cb(gpointer callback_data, guint callbac
 				account = account_find_from_id(item->prefs->default_account);
 
 		 	if (!account) 
-				account = cur_account;
+				account = account_get_cur_account();
 			
 			if (!account)
 				goto bail;
@@ -188,10 +183,10 @@ static void create_meeting_from_message_cb(gpointer callback_data, guint callbac
 			} else {
 				g_snprintf(uid, sizeof(uid), "%s", "");
 			}
-			generate_msgid(uid, 255);
+			generate_msgid(uid, 255, account->address);
 			
 			event = vcal_manager_new_event(uid,
-					org, NULL, summary, description, 
+					org, NULL, NULL/*location*/, summary, description, 
 					dtstart, dtend, recur, tzid, url, method, sequence, 
 					ICAL_VTODO_COMPONENT);
 			
@@ -223,12 +218,11 @@ bail:
 	STATUSBAR_POP(mainwin);
 	inc_unlock();
 	folder_item_update_thaw();
-	gtk_clist_thaw(GTK_CLIST(summaryview->ctree));
+	gtk_cmclist_thaw(GTK_CMCLIST(summaryview->ctree));
 	main_window_cursor_normal(summaryview->mainwin);
 	g_slist_free(msglist);
 }
 
-
 static gchar *get_tmpfile(VCalViewer *vcalviewer)
 {
 	gchar *tmpfile = NULL;
@@ -267,7 +261,7 @@ static void vcal_viewer_clear_viewer(MimeViewer *_mimeviewer)
 	vcalviewer->file = NULL;
 	if (vcalviewer->tmpfile) {
 		debug_print("unlinking %s\n", vcalviewer->tmpfile);
-		unlink(vcalviewer->tmpfile);
+		g_unlink(vcalviewer->tmpfile);
 		g_free(vcalviewer->tmpfile);
 		vcalviewer->tmpfile = NULL;
 	}
@@ -285,8 +279,8 @@ static VCalEvent *vcalviewer_get_component(const gchar *file, const gchar *chars
 
 	g_return_val_if_fail(file != NULL, NULL);
 
-	if ((fp = fopen(file, "rb")) == NULL) {
-		FILE_OP_ERROR(file, "fopen");
+	if ((fp = g_fopen(file, "rb")) == NULL) {
+		FILE_OP_ERROR(file, "g_fopen");
 		return NULL;
 	}
 
@@ -331,6 +325,7 @@ static void vcalviewer_reset(VCalViewer *vcalviewer)
 {
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->type), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->who), "-");
+	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->summary), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->description), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->start), "-");
@@ -525,6 +520,13 @@ void vcalviewer_display_event (VCalViewer *vcalviewer, VCalEvent *event)
 		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->who), "-");
 	}
 
+/* location */
+	if (event->location && *(event->location)) {
+		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location), event->location);
+	} else {
+		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location), "-");
+	}
+
 /* summary */
 	if (event->summary && *(event->summary)) {
 		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->summary), event->summary);
@@ -649,6 +651,12 @@ gchar *vcalviewer_get_uid_from_mimeinfo(MimeInfo *mimeinfo)
 	gchar *res = NULL;
 	VCalEvent *event = NULL;
 
+	if (!charset)
+		charset = CS_WINDOWS_1252;
+	
+	if (!strcasecmp(charset, CS_ISO_8859_1))
+		charset = CS_WINDOWS_1252;
+
 	if (procmime_get_part(tmpfile, mimeinfo) < 0) {
 		g_warning("Can't get mimepart file");	
 		g_free(tmpfile);
@@ -678,8 +686,11 @@ static void vcalviewer_get_request_values(VCalViewer *vcalviewer, MimeInfo *mime
 		return;
 
 	if (!charset)
-		charset=CS_ISO_8859_1;
+		charset = CS_WINDOWS_1252;
 	
+	if (!strcasecmp(charset, CS_ISO_8859_1))
+		charset = CS_WINDOWS_1252;
+
 	/* see if we have it registered and more recent */
 	saved_event = vcal_manager_load_event(vcalviewer->event->uid);
 	if (saved_event && saved_event->sequence >= vcalviewer->event->sequence) {
@@ -711,7 +722,10 @@ static void vcalviewer_get_reply_values(VCalViewer *vcalviewer, MimeInfo *mimein
 		return;
 
 	if (!charset)
-		charset=CS_ISO_8859_1;
+		charset = CS_WINDOWS_1252;
+	
+	if (!strcasecmp(charset, CS_ISO_8859_1))
+		charset = CS_WINDOWS_1252;
 
 	if (!vcalviewer->event->answers || g_slist_length(vcalviewer->event->answers) > 1) {
 		g_warning("strange, no answers or more than one\n");
@@ -738,7 +752,7 @@ static void vcalviewer_get_reply_values(VCalViewer *vcalviewer, MimeInfo *mimein
 	g_free(label);
 
 	saved_event = vcal_manager_load_event(vcalviewer->event->uid);
-	if (saved_event) {
+	if (saved_event && answer) {
 		vcal_manager_update_answer(saved_event, 
 			answer->attendee, answer->name, answer->answer, answer->cutype);
 		vcal_manager_save_event(saved_event, TRUE);
@@ -762,6 +776,9 @@ static void vcalviewer_get_reply_values(VCalViewer *vcalviewer, MimeInfo *mimein
 		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->who), "-");
 	}
 	
+	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location),
+		vcalviewer->event->location?vcalviewer->event->location:"-");
+
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->summary), 
 		vcalviewer->event->summary?vcalviewer->event->summary:"-");
 
@@ -792,6 +809,12 @@ static void vcalviewer_get_event(VCalViewer *vcalviewer, MimeInfo *mimeinfo)
 	gchar *tmpfile = get_tmpfile(vcalviewer);
 	const gchar *charset = procmime_mimeinfo_get_parameter(mimeinfo, "charset");
 
+	if (!charset)
+		charset = CS_WINDOWS_1252;
+	
+	if (!strcasecmp(charset, CS_ISO_8859_1))
+		charset = CS_WINDOWS_1252;
+	
 	if (vcalviewer->event) {
 		vcal_manager_free_event(vcalviewer->event);
 		vcalviewer->event = NULL;
@@ -850,15 +873,16 @@ static void vcal_viewer_show_mimepart(MimeViewer *_mimeviewer, const gchar *file
 	GTK_EVENTS_FLUSH();
 	gtk_widget_set_size_request(vcalviewer->description, 
 		vcalviewer->scrolledwin->allocation.width - 200, -1);
+	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->location), TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->summary), TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->description), TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->attendees), FALSE);
 	
-	if (prefs_common.textfont) {
+	if (prefs_common_get_prefs()->textfont) {
 		PangoFontDescription *font_desc;
 
 		font_desc = pango_font_description_from_string
-						(prefs_common.textfont);
+						(prefs_common_get_prefs()->textfont);
 		if (font_desc) {
 			gtk_widget_modify_font(
 				vcalviewer->description, font_desc);
@@ -931,7 +955,6 @@ void vcalendar_refresh_folder_contents(FolderItem *item)
 		folder_item_scan(item);
 		if (mainwin->summaryview->folder_item == item) {
 			summary_show(mainwin->summaryview, item);
-			vcal_folder_refresh_cal(item);
 		}
 	}
 }
@@ -991,7 +1014,6 @@ void vcalendar_cancel_meeting(FolderItem *item, const gchar *uid)
 			if (folder && redisp) {
 				MainWindow *mainwin = mainwindow_get_mainwindow();
 				summary_show(mainwin->summaryview, item);
-				vcal_folder_refresh_cal(item);
 			}
 			return;
 		}
@@ -1000,7 +1022,7 @@ void vcalendar_cancel_meeting(FolderItem *item, const gchar *uid)
 	vcal_manager_save_event(event, TRUE);
 	
 	file = vcal_manager_get_event_file(event->uid);
-	unlink(file);
+	g_unlink(file);
 	vcal_manager_free_event(event);
 	g_free(file);
 	if (folder)
@@ -1008,7 +1030,6 @@ void vcalendar_cancel_meeting(FolderItem *item, const gchar *uid)
 	if (folder && redisp) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
 		summary_show(mainwin->summaryview, item);
-		vcal_folder_refresh_cal(item);
 	}
 
 	return;
@@ -1029,7 +1050,7 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 	gint index = gtk_combo_box_get_active(GTK_COMBO_BOX(vcalviewer->answer));
 	enum icalparameter_partstat reply[3] = {ICAL_PARTSTAT_ACCEPTED, ICAL_PARTSTAT_TENTATIVE, ICAL_PARTSTAT_DECLINED};
 	PrefsAccount *account = NULL;
-	
+	VCalEvent *saved_event = NULL, *event = NULL;
 	debug_print("index chosen %d\n", index);
 	
 	if (index < 0 || index > 2) {
@@ -1042,7 +1063,18 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 		g_warning("can't get event\n");
 		return TRUE;
 	}
-	account = vcal_manager_get_account_from_event(vcalviewer->event);
+
+/* see if we have it registered and more recent */
+	event = vcalviewer->event;
+	saved_event = vcal_manager_load_event(vcalviewer->event->uid);
+	if (saved_event && saved_event->sequence >= vcalviewer->event->sequence) {
+		saved_event->method = vcalviewer->event->method;
+		event = saved_event;
+	} else if (saved_event) {
+		vcal_manager_free_event(saved_event);
+		saved_event = NULL;
+	}
+	account = vcal_manager_get_account_from_event(event);
 	
 	if (!account) {
 		AlertValue val = alertpanel_full(_("No account found"), 
@@ -1052,27 +1084,31 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 				   	NULL, ALERT_QUESTION, G_ALERTDEFAULT);
 		if (val == G_ALERTALTERNATE) {		
 			account = account_get_default();
-			vcal_manager_update_answer(vcalviewer->event, account->address, 
+			vcal_manager_update_answer(event, account->address, 
 					account->name,
 					ICAL_PARTSTAT_NEEDSACTION, 
 					ICAL_CUTYPE_INDIVIDUAL);
-		} else
+		} else {
+			if (saved_event)
+				vcal_manager_free_event(saved_event);
 			return TRUE;
+		}
 	}
 	
-	vcal_manager_update_answer(vcalviewer->event, account->address, account->name, reply[index], 0);
+	vcal_manager_update_answer(event, account->address, account->name, reply[index], 0);
 	
-	if (vcalviewer->event->organizer && *(vcalviewer->event->organizer) && 
-	    !vcal_manager_reply(account, vcalviewer->event)) {
+	if (event->organizer && *(event->organizer) && 
+	    !vcal_manager_reply(account, event)) {
 		g_warning("couldn't send reply\n");
 	} else {
 		debug_print("no organizer, not sending answer\n");
 	}
 	
-	vcal_manager_save_event(vcalviewer->event, TRUE);
+	vcal_manager_save_event(event, TRUE);
 
-	vcalviewer_display_event(vcalviewer, vcalviewer->event);
-	
+	vcalviewer_display_event(vcalviewer, event);
+	if (saved_event)
+		vcal_manager_free_event(saved_event);
         return TRUE;
 };
 
@@ -1166,6 +1202,7 @@ MimeViewer *vcal_viewer_create(void)
 	vcalviewer->who = gtk_label_new("who");
 	vcalviewer->start = gtk_label_new("start");
 	vcalviewer->end = gtk_label_new("end");
+	vcalviewer->location = gtk_label_new("location");
 	vcalviewer->summary = gtk_label_new("summary");
 	vcalviewer->description = gtk_label_new("description");
 	vcalviewer->attendees = gtk_label_new("attendees");
@@ -1201,6 +1238,7 @@ MimeViewer *vcal_viewer_create(void)
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->who), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->start), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->end), TRUE);
+	gtk_label_set_selectable(GTK_LABEL(vcalviewer->location), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->summary), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->description), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->attendees), TRUE);
@@ -1219,6 +1257,7 @@ MimeViewer *vcal_viewer_create(void)
 
 	TABLE_ADD_LINE(_("Event:"), vcalviewer->type);
 	TABLE_ADD_LINE(_("Organizer:"), vcalviewer->who);
+	TABLE_ADD_LINE(_("Location:"), vcalviewer->location);
 	TABLE_ADD_LINE(_("Summary:"), vcalviewer->summary);
 	TABLE_ADD_LINE(_("Starting:"), vcalviewer->start);
 	TABLE_ADD_LINE(_("Ending:"), vcalviewer->end);
@@ -1256,7 +1295,7 @@ static gint vcal_webcal_check(gpointer data)
 {
 	Folder *root = folder_find_from_name ("vCalendar", vcal_folder_get_class());
 
-	if (prefs_common.work_offline)
+	if (prefs_common_get_prefs()->work_offline)
 		return TRUE;
 	
 	manual_update = FALSE;
@@ -1265,11 +1304,12 @@ static gint vcal_webcal_check(gpointer data)
 	return TRUE;
 }
 
+static guint context_menu_id = 0;
+static guint main_menu_id = 0;
+
 void vcalendar_init(void)
 {
-	GtkItemFactory *ifactory;
 	MainWindow *mainwin = mainwindow_get_mainwindow();
-	SummaryView *summaryview = mainwin->summaryview;
 	Folder *folder = NULL;
 	gchar *directory = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S,
 				"vcalendar", NULL);
@@ -1302,22 +1342,25 @@ void vcalendar_init(void)
 	
 	vcal_folder_gtk_init();
 
-	alert_timeout_tag = gtk_timeout_add(60*1000, 
+	alert_timeout_tag = g_timeout_add(60*1000, 
 				(GtkFunction)vcal_meeting_alert_check, 
 				(gpointer)NULL);
-	scan_timeout_tag = gtk_timeout_add(3600*1000, 
+	scan_timeout_tag = g_timeout_add(3600*1000, 
 				(GtkFunction)vcal_webcal_check, 
 				(gpointer)NULL);
-	if (prefs_common.enable_color) {
-		gtkut_convert_int_to_gdk_color(prefs_common.uri_col,
+	if (prefs_common_get_prefs()->enable_color) {
+		gtkut_convert_int_to_gdk_color(prefs_common_get_prefs()->uri_col,
 				       &uri_color);
 	}
 
-	vcalendar_main_menu.path = _(vcalendar_main_menu.path);
-	vcalendar_context_menu.path = _(vcalendar_context_menu.path);
-	ifactory = gtk_item_factory_from_widget(mainwin->menubar);
-	gtk_item_factory_create_item(ifactory, &vcalendar_main_menu, mainwin, 1);
-	gtk_item_factory_create_item(summaryview->popupfactory, &vcalendar_context_menu, summaryview, 1);
+	gtk_action_group_add_actions(mainwin->action_group, vcalendar_main_menu,
+			1, (gpointer)mainwin);
+	MENUITEM_ADDUI_ID_MANAGER(mainwin->ui_manager, "/Menu/Message", "CreateMeeting", 
+			  "Message/CreateMeeting", GTK_UI_MANAGER_MENUITEM,
+			  main_menu_id)
+	MENUITEM_ADDUI_ID_MANAGER(mainwin->ui_manager, "/Menus/SummaryViewPopup", "CreateMeeting", 
+			  "Message/CreateMeeting", GTK_UI_MANAGER_MENUITEM,
+			  context_menu_id)
 	END_TIMING();
 }
 
@@ -1326,9 +1369,7 @@ void vcalendar_done(void)
 	MainWindow *mainwin = mainwindow_get_mainwindow();
 	FolderView *folderview = NULL;
 	FolderItem *fitem = NULL;
-	GtkItemFactory *ifactory;
 	SummaryView *summaryview = NULL;
-	GtkWidget *widget;
 
 	icalmemory_free_ring();
 
@@ -1350,17 +1391,13 @@ void vcalendar_done(void)
 	folder_unregister_class(vcal_folder_get_class());
 	vcal_folder_gtk_done();
 	vcal_prefs_done();
-	gtk_timeout_remove(alert_timeout_tag);
+	g_source_remove(alert_timeout_tag);
 	alert_timeout_tag = 0;
-	gtk_timeout_remove(scan_timeout_tag);
+	g_source_remove(scan_timeout_tag);
 	scan_timeout_tag = 0;
 
-	ifactory = gtk_item_factory_from_widget(mainwin->menubar);
-	widget = gtk_item_factory_get_widget(ifactory, vcalendar_main_menu.path);
-	gtk_widget_destroy(widget);
-	gtk_item_factory_delete_item(ifactory, vcalendar_main_menu.path);
-
-	widget = gtk_item_factory_get_widget(summaryview->popupfactory, vcalendar_context_menu.path);
-	gtk_widget_destroy(widget);
-	gtk_item_factory_delete_item(summaryview->popupfactory, vcalendar_context_menu.path);
+	MENUITEM_REMUI_MANAGER(mainwin->ui_manager,mainwin->action_group, "Message/CreateMeeting", main_menu_id);
+	main_menu_id = 0;
+	MENUITEM_REMUI_MANAGER(mainwin->ui_manager,mainwin->action_group, "Message/CreateMeeting", context_menu_id);
+	context_menu_id = 0;
 }
